@@ -309,26 +309,5 @@ impl Stats for &[f64] {
         }
         Ok(rank)
     }
-    
-    /// Returns vector of i64 ranks; 
-    /// ranked from the smallest number in self (rank 0) to the biggest (rank n-1).
-    fn iranks(self) -> Result<Vec<i64>> {
-        let n = self.len();
-        let mut rank = vec![0_i64; n];
-        // make each of n*(n-1)/2 comparisons just once
-        for i in 1..n {
-            let x = self[i];
-            for j in 0..i {
-                if x > self[j] {
-                    rank[i] += 1_i64; // demoting i
-                }
-                else if x < self[j] {
-                    rank[j] += 1_i64; // demoting j                  
-                };
-                // items are equal, not demoting any
-            }
-        }
-        Ok(rank)
-    }
 */
 }
