@@ -3,20 +3,20 @@ use anyhow::{ensure, Result};
 pub use indxvec::merge::sortm;
 
 impl Stats for &[i64] {
-    /// Arithmetic mean of an i64 slice
+    /// Arithmetic mean of an f64 slice
     /// # Example
     /// ```
     /// use rstats::Stats;
-    /// let v1:Vec<i64> = vec![1,2,3,4,5,6,7,8,9,10,11,12,13,14];
+    /// let v1 = vec![1_i64,2,3,4,5,6,7,8,9,10,11,12,13,14];
     /// assert_eq!(v1.as_slice().amean().unwrap(),7.5_f64);
     /// ```
     fn amean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, "{} sample is empty!", here!());
+        ensure!(n > 0, "{} sample is empty!",here!());
         Ok(self.iter().map(|&x| x as f64).sum::<f64>() / (n as f64))
     }
 
-    /// Arithmetic mean and standard deviation of an i64 slice
+    /// Arithmetic mean and (population) standard deviation of an f64 slice
     /// # Example
     /// ```
     /// use rstats::Stats;
@@ -27,14 +27,13 @@ impl Stats for &[i64] {
     /// ```
     fn ameanstd(self) -> Result<MStats> {
         let n = self.len();
-        ensure!(n > 0, "{} sample is empty!", here!());
+        ensure!(n > 0, "{} sample is empty!",here!());
         let mut sx2 = 0_f64;
         let mean = self
             .iter()
             .map(|&x| {
-                let lx = x as f64;
-                sx2 += lx * lx;
-                lx
+                sx2 += x as f64 * x as f64;
+                x as f64
             })
             .sum::<f64>()
             / (n as f64);
@@ -44,7 +43,7 @@ impl Stats for &[i64] {
         })
     }
 
-    /// Linearly weighted arithmetic mean of an i64 slice.     
+    /// Linearly weighted arithmetic mean of an f64 slice.     
     /// Linearly descending weights from n down to one.    
     /// Time dependent data should be in the stack order - the last being the oldest.
     /// # Example
@@ -56,18 +55,18 @@ impl Stats for &[i64] {
     fn awmean(self) -> Result<f64> {
         let n = self.len();
         ensure!(n > 0, "{} sample is empty!", here!());
-        let mut w = (n + 1) as f64; // descending linear weights
+        let mut iw = (n + 1) as f64; // descending linear weights
         Ok(self
             .iter()
             .map(|&x| {
-                w -= 1.;
-                w * x as f64
+                iw -= 1_f64;
+                iw * x as f64
             })
             .sum::<f64>()
             / wsum(n))
     }
 
-    /// Liearly weighted arithmetic mean and standard deviation of an i64 slice.    
+    /// Liearly weighted arithmetic mean and standard deviation of an f64 slice.    
     /// Linearly descending weights from n down to one.    
     /// Time dependent data should be in the stack order - the last being the oldest.
     /// # Example
@@ -80,19 +79,19 @@ impl Stats for &[i64] {
     /// ```
     fn awmeanstd(self) -> Result<MStats> {
         let n = self.len();
-        ensure!(n > 0, "{} sample is empty!", here!());
+        ensure!(n > 0, "{} sample is empty!", here!());        
         let mut sx2 = 0_f64;
         let mut w = n as f64; // descending linear weights
         let mean = self
             .iter()
             .map(|&x| {
-                let lx = x as f64;
-                let wx = w * lx;
-                sx2 += wx * lx;
-                w -= 1.;
+                let fx = x as f64;
+                let wx = w * fx;
+                sx2 += wx * fx;
+                w -= 1_f64;
                 wx
             })
-            .sum::<f64>() as f64
+            .sum::<f64>()
             / wsum(n);
         Ok(MStats {
             mean: mean,
@@ -100,25 +99,25 @@ impl Stats for &[i64] {
         })
     }
 
-    /// Harmonic mean of an i64 slice.
+    /// Harmonic mean of an f64 slice.
     /// # Example
     /// ```
     /// use rstats::Stats;
-    /// let v1 = vec![1_i64,2,3,4,5,6,7,8,9,10,11,12,13,14];
+    /// let v1 = vec![1_i64,2,3,4,5,6,7,8,9,10,11,12,13,14]; 
     /// assert_eq!(v1.as_slice().hmean().unwrap(),4.305622526633627_f64);
     /// ```
     fn hmean(self) -> Result<f64> {
         let n = self.len();
-        ensure!(n > 0, "{} sample is empty!", here!());
+        ensure!(n > 0, "{} sample is empty!", here!());        
         let mut sum = 0_f64;
         for &x in self {
-            ensure!(x!=0_i64,"{} does not accept zero valued data!",here!());
-            sum += 1.0 / (x as f64)
+            let fx =  x as f64;
+            ensure!( fx.is_normal(),"{} does not accept zero valued data!",here!());         
+            sum += 1.0 / fx
         }
         Ok(n as f64 / sum)
     }
-
-    /// Linearly weighted harmonic mean of an i64 slice.    
+    /// Linearly weighted harmonic mean of an f64 slice.    
     /// Linearly descending weights from n down to one.    
     /// Time dependent data should be in the stack order - the last being the oldest.
     /// # Example
@@ -133,8 +132,9 @@ impl Stats for &[i64] {
         let mut sum = 0_f64;
         let mut w = n as f64;
         for &x in self {
-            ensure!(x!=0_i64,"{} does not accept zero valued data!",here!());
-            sum += w / x as f64;
+            let fx = x as f64;
+            ensure!(fx.is_normal(),"{} does not accept zero valued data!",here!());
+            sum += w / fx;
             w -= 1_f64;
         }
         Ok(wsum(n) / sum)
@@ -156,8 +156,9 @@ impl Stats for &[i64] {
         ensure!(n > 0, "{} sample is empty!", here!());
         let mut sum = 0_f64;
         for &x in self {
-            ensure!(x!=0_i64,"{} does not accept zero valued data!",here!());
-            sum += (x as f64).ln()
+            let fx = x as f64;
+            ensure!( fx.is_normal(),"{} does not accept zero valued data!",here!());        
+            sum += fx.ln()
         }
         Ok((sum / (n as f64)).exp())
     }
@@ -181,14 +182,15 @@ impl Stats for &[i64] {
         let mut w = n as f64; // descending weights
         let mut sum = 0_f64;
         for &x in self {
-            ensure!(x!=0_i64,"{} does not accept zero valued data!",here!());
-            sum += w * (x as f64).ln();
+            let fx = x as f64;
+            ensure!(fx.is_normal(),"{} does not accept zero valued data!",here!());
+            sum += w * fx.ln();
             w -= 1_f64;
         }
         Ok((sum / wsum(n)).exp())
     }
 
-    /// Geometric mean and std ratio of an i64 slice.  
+    /// Geometric mean and std ratio of an f64 slice.  
     /// Zero valued data is not allowed.  
     /// Std of ln data becomes a ratio after conversion back.
     /// # Example
@@ -205,8 +207,9 @@ impl Stats for &[i64] {
         let mut sum = 0_f64;
         let mut sx2 = 0_f64;
         for &x in self {
-            ensure!(x!=0_i64,"{} does not accept zero valued data!",here!());
-            let lx = (x as f64).ln();
+            let fx = x as f64;
+            ensure!(fx.is_normal(),"{} does not accept zero valued data!",here!());
+            let lx = fx.ln();
             sum += lx;
             sx2 += lx * lx
         }
@@ -228,13 +231,14 @@ impl Stats for &[i64] {
     /// ```
     fn gwmeanstd(self) -> Result<MStats> {
         let n = self.len();
-        ensure!(n > 0, "{} sample is empty!", here!());
+        ensure!(n > 0, "{} sample is empty!", here!()); 
         let mut w = n as f64; // descending weights
         let mut sum = 0_f64;
         let mut sx2 = 0_f64;
         for &x in self {
-            ensure!(x!=0_i64,"{} does not accept zero valued data!",here!());
-            let lnx = (x as f64).ln();
+            let fx = x as f64;
+            ensure!(fx.is_normal(),"{} does not accept zero valued data!",here!());
+            let lnx = fx.ln();
             sum += w * lnx;
             sx2 += w * lnx * lnx;
             w -= 1_f64;
@@ -246,43 +250,44 @@ impl Stats for &[i64] {
         })
     }
 
-    /// Median. 
+    /// Median of an f64 slice
     /// # Example
     /// ```
     /// use rstats::Stats;
-    /// let v1 = vec![1_i64,2,3,4,5,6,7,8,9,10,11,12,13,14,15];
+    /// let v1 = vec![1_i64,2,3,4,5,6,7,8,9,10,11,12,13,14];
     /// let res = v1.as_slice().median().unwrap();
-    /// assert_eq!(res.median,8.);
-    /// assert_eq!(res.lquartile,4.5);
-    /// assert_eq!(res.uquartile,11.5);
+    /// assert_eq!(res.median,7.5_f64);
+    /// assert_eq!(res.lquartile,4.25_f64);
+    /// assert_eq!(res.uquartile,10.75_f64);
     /// ```
     fn median(self) -> Result<Med> {
         let gaps = self.len()-1;
         let mid = gaps / 2;
         let quarter = gaps / 4;
         let threeq = 3 * gaps / 4;
-        let qrem = gaps % 4;
-        let mut v:Vec<i64> = self.to_vec();
-        v.sort_unstable();     
+        let v = sortm(self,true);     
         let mut result: Med = Default::default();
-        result.median = if 2*mid < gaps { (v[mid] + v[mid + 1]) as f64 / 2.0 }
+        result.median = if 2*mid < gaps { (v[mid] as f64 + v[mid + 1] as f64) / 2.0 }
             else { v[mid] as f64 };
-        if qrem == 0 {
+        match gaps % 4 {
+        0 => {
             result.lquartile = v[quarter] as f64;
             result.uquartile = v[threeq] as f64;
-            return Ok(result) };
-        if qrem == 1 {
-            result.lquartile = (3*v[quarter] + v[quarter+1]) as f64 / 4.;
-            result.uquartile = (v[threeq] + 3*v[threeq+1]) as f64 / 4.;
-            return Ok(result) };
-        if qrem == 2 {
-            result.lquartile = (v[quarter]+v[quarter+1]) as f64 / 2.;
-            result.uquartile = (v[threeq] + v[threeq+1]) as f64 / 2.;
-            return Ok(result) };
-        if qrem == 3 {
-            result.lquartile = (v[quarter] + 3*v[quarter+1]) as f64 / 4.;
-            result.uquartile = (3*v[threeq] + v[threeq+1]) as f64 / 4.
-        };
+            return Ok(result) },
+        1 => {
+            result.lquartile = (3.*v[quarter] as f64 + v[quarter+1] as f64) / 4.;
+            result.uquartile = (v[threeq] as f64 + 3.*v[threeq+1] as f64) / 4.;
+            return Ok(result) },
+        2 => {
+            result.lquartile = (v[quarter] as f64 +v[quarter+1]as f64) / 2.;
+            result.uquartile = (v[threeq] as f64 + v[threeq+1] as f64) / 2.;
+            return Ok(result) },
+        3 => {
+            result.lquartile = (v[quarter] as f64 + 3.*v[quarter+1] as f64) / 4.;
+            result.uquartile = (3.*v[threeq] as f64 + v[threeq+1] as f64) / 4.
+            },
+        _ => { }  
+        }
         Ok(result)       
-    }  
+    } 
 }
